aligned_data_section_start

Function aligned_data_section_start 

pub fn aligned_data_section_start(metadata_size: usize) -> usize
Calculate the byte offset where the tensor data section starts.

The data section is padded to start at a 256-byte aligned position so that all tensor offsets (which are relative to data section) result in properly aligned absolute file positions for mmap zero-copy access.

This function must be used consistently by both writer and reader.